//////////////////////////
// ******************** //
//     Breakpoints      //
// ******************** //
//////////////////////////

$screen-sm:   450px;
$screen-md:   600px;
$screen-lg:   768px;
$screen-xlg:  1000px;
$screen-xxl:  1200px;

// So media queries don't overlap when required, provide a maximum
$screen-xs-max:  ($screen-sm - 1);
$screen-sm-max:  ($screen-md - 1);
$screen-md-max:  ($screen-lg - 1);
$screen-lg-max:  ($screen-xlg - 1);
$screen-xlg-max: ($screen-xxl - 1);

@-ms-viewport {
  width: device-width;
}